use actix_identity::Identity;
use actix_web::{web, HttpResponse, Responder};
use askama::Template;
use askama_actix::TemplateToResponse;
use sqlx::PgPool;

use crate::models::{Area, Location, Role, User};

#[derive(Template)]
#[template(path = "locations.html")]
pub struct LocationsTemplate {
    user: User,
    area: Area,
    locations: Vec<Location>
}

#[actix_web::get("/locations")]
pub async fn get(user: Identity, pool: web::Data<PgPool>) -> impl Responder {
    let current_user = User::read_by_id(pool.get_ref(), user.id().unwrap().parse().unwrap()).await.unwrap();

    if current_user.role == Role::AreaManager {
        if let Ok(locations) = Location::read_by_area(pool.get_ref(), current_user.area_id).await {
            let area = Area::read_by_id(pool.get_ref(), current_user.area_id).await.unwrap();

            let template = LocationsTemplate { user: current_user, area, locations};

            return template.to_response()
        }
    }

    return HttpResponse::BadRequest().body("Fehler beim Zugriff auf die Veranstaltungsorte!");
}
